==> cueplot-0.0.2-src.tar.gz: cueplot-0.0.2-src/gui/opt/AxisRangeOptionWidget.h <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef AXIS_RANGE_OPTION_WIDGET_INCLUDED
#define AXIS_RANGE_OPTION_WIDGET_INCLUDED

#include "AxisOptionWidget.h"

class AxisRange;

class QLineEdit;

class AxisRangeOptionWidget : public AxisOptionWidget
{
	Q_OBJECT

	public:
		AxisRangeOptionWidget(QWidget *parent = 0);
		~AxisRangeOptionWidget();

		void construct();

	private:
		// don't implement these
		AxisRangeOptionWidget(const AxisRangeOptionWidget &);
		AxisRangeOptionWidget &operator=(const AxisRangeOptionWidget &);

		void init();
		void apply();
		void constructWidget(QWidget *widget);
		void setOption(int axis);
		void setWidget(int axis);
		AxisRange *axisRange;
		QLineEdit *minLineEdit;
		QLineEdit *maxLineEdit;
};
#endif // AXIS_RANGE_OPTION_WIDGET_INCLUDED

==> cueplot-0.0.3-src.tar.gz: cueplot-0.0.3-src/gui/opt/AxisRangeOptionWidget.h <==
/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef AXIS_RANGE_OPTION_WIDGET_INCLUDED
#define AXIS_RANGE_OPTION_WIDGET_INCLUDED

#include "AxisOptionWidget.h"

class AxisRange;

class QLineEdit;

class AxisRangeOptionWidget : public AxisOptionWidget
{
	Q_OBJECT

	public:
		explicit AxisRangeOptionWidget(QWidget *parent = 0);
		~AxisRangeOptionWidget();

		void construct();

	private:
		// don't implement these
		AxisRangeOptionWidget(const AxisRangeOptionWidget &);
		AxisRangeOptionWidget &operator=(const AxisRangeOptionWidget &);

		void init();
		void apply();
		void constructWidget(QWidget *widget);
		void setOption(int axis);
		void setWidget(int axis);
		AxisRange *axisRange;
		QLineEdit *minLineEdit;
		QLineEdit *maxLineEdit;
};
#endif // AXIS_RANGE_OPTION_WIDGET_INCLUDED
